@@ -1344,6 +1344,11 @@ conn_set_session(connectionObject *self, int autocommit,
         }
     }
 
+    Py_BLOCK_THREADS;
+    conn_notifies_process(self);
+    conn_notice_process(self);
+    Py_UNBLOCK_THREADS;
+
     if (autocommit != SRV_STATE_UNCHANGED) {
         self->autocommit = autocommit;
     }
@@ -1408,6 +1413,11 @@ conn_set_client_encoding(connectionObject *self, const char *pgenc)
         goto endlock;
     }
 
+    Py_BLOCK_THREADS;
+    conn_notifies_process(self);
+    conn_notice_process(self);
+    Py_UNBLOCK_THREADS;
+
 endlock:
     pthread_mutex_unlock(&self->lock);
     Py_END_ALLOW_THREADS;
