@@ -1,6 +1,7 @@
 /* conninfo_type.c - present information about the libpq connection
  *
  * Copyright (C) 2018-2019  Daniele Varrazzo <daniele.varrazzo@gmail.com>
+ * Copyright (C) 2020-2021 The Psycopg Team
  *
  * This file is part of psycopg.
  *
@@ -147,7 +148,7 @@ port_get(connInfoObject *self)
 
 
 static const char options_doc[] =
-"The command-line options passed in the the connection request.\n"
+"The command-line options passed in the connection request.\n"
 "\n"
 ".. seealso:: libpq docs for `PQoptions()`__ for details.\n"
 ".. __: https://www.postgresql.org/docs/current/static/libpq-status.html"
@@ -362,7 +363,7 @@ socket_get(connInfoObject *self)
 
 
 static const char backend_pid_doc[] =
-"The process ID (PID) of the backend process handling this connection.\n"
+"The process ID (PID) of the backend process you connected to.\n"
 "\n"
 ":type: `!int`\n"
 "\n"
