@@ -3,6 +3,7 @@
 # psycopg2 test suite
 #
 # Copyright (C) 2007-2019 Federico Di Gregorio  <fog@debian.org>
+# Copyright (C) 2020-2021 The Psycopg Team
 #
 # psycopg2 is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Lesser General Public License as published
@@ -57,9 +58,6 @@ from . import test_types_basic
 from . import test_types_extras
 from . import test_with
 
-if sys.version_info[:2] < (3, 6):
-    from . import test_async_keyword
-
 
 def test_suite():
     # If connection to test db fails, bail out early.
@@ -75,8 +73,6 @@ def test_suite():
 
     suite = unittest.TestSuite()
     suite.addTest(test_async.test_suite())
-    if sys.version_info[:2] < (3, 6):
-        suite.addTest(test_async_keyword.test_suite())
     suite.addTest(test_bugX000.test_suite())
     suite.addTest(test_bug_gc.test_suite())
     suite.addTest(test_cancel.test_suite())
