@@ -219,7 +219,7 @@ class CallbackErrorTestCase(ConnectingTestCase):
 
         self.fail("you should have had a success or an error by now")
 
-    @skip_if_crdb("named cursor")
+    @skip_if_crdb("named cursor", version="< 22.1")
     def test_errors_named_cursor(self):
         for i in range(100):
             self.to_error = None
